# USER API Documentation

**Total Endpoints**: 3

---

## 1. GET /api/v1/user/onboarding-questionnaire

**Summary:** Get Onboarding Questionnaire

**Operation ID:** `get_onboarding_questionnaire_api_v1_user_onboarding_questionnaire_get`

---

## 2. POST /api/v1/user/save-onboarding

**Summary:** Save Onboarding Questionnaire

**Operation ID:** `save_onboarding_questionnaire_api_v1_user_save_onboarding_post`

### Request Body

**Status:** Required

---

## 3. POST /api/v1/user/consent

**Summary:** Add User Consent

**Operation ID:** `add_user_consent_api_v1_user_consent_post`

### Request Body

**Status:** Required

---

